/*
 *
 *  Kepas - KDE Easy Publish and Share
 *
 *  Copyright (C) 2008  Tom Patzig <tpatzig@suse.de>
 *
 *  This file is part of kepas.
 *
 *  kepas is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  kepas is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with kepas; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
*/

#ifndef BUDDYCONTENT_H
#define BUDDYCONTENT_H


class BuddyContent
{

public:
	BuddyContent(QString m_name, QString m_hostname, int m_port, QString m_SN, QString m_llname, QWidget* parent) : name(m_name), 	hostname(m_hostname), port(m_port), SN(m_SN) ,llname(m_llname) {};
	
	QString name;
	QString hostname;
	int port;
	QString SN;
	QString llname;
	QString http;

};



#endif
